<?php

namespace Litepie\Location\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Location\Interfaces\LocationRepositoryInterface;

class LocationPublicController extends BaseController
{
    // use LocationWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\Location\Interfaces\LocationRepositoryInterface $location
     *
     * @return type
     */
    public function __construct(LocationRepositoryInterface $location)
    {
        $this->repository = $location;
        parent::__construct();
    }

    /**
     * Show location's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $locations = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('$location::location.names'))
            ->view('location::location.index')
            ->data(compact('locations'))
            ->output();
    }


    /**
     * Show location.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $location = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($$location->name . trans('location::location.name'))
            ->view('location::location.show')
            ->data(compact('location'))
            ->output();
    }

}
