<?php

namespace Litepie\Location\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Location\Models\Location;

class LocationPolicy
{

    /**
     * Determine if the given user can view the location.
     *
     * @param UserPolicy $user
     * @param Location $location
     *
     * @return bool
     */
    public function view(UserPolicy $user, Location $location)
    {
        if ($user->canDo('location.location.view') && $user->isAdmin()) {
            return true;
        }

        return $location->user_id == user_id() && $location->user_type == user_type();
    }

    /**
     * Determine if the given user can create a location.
     *
     * @param UserPolicy $user
     * @param Location $location
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('location.location.create');
    }

    /**
     * Determine if the given user can update the given location.
     *
     * @param UserPolicy $user
     * @param Location $location
     *
     * @return bool
     */
    public function update(UserPolicy $user, Location $location)
    {
        if ($user->canDo('location.location.edit') && $user->isAdmin()) {
            return true;
        }

        return $location->user_id == user_id() && $location->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given location.
     *
     * @param UserPolicy $user
     * @param Location $location
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Location $location)
    {
        return $location->user_id == user_id() && $location->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given location.
     *
     * @param UserPolicy $user
     * @param Location $location
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Location $location)
    {
        if ($user->canDo('location.location.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given location.
     *
     * @param UserPolicy $user
     * @param Location $location
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Location $location)
    {
        if ($user->canDo('location.location.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
